@@ -19,6 +19,9 @@ class ChannelManager(TreeManager):
             return super(ChannelManager, self).get_query_set().filter(
                 site__domain=site, homepage=True, published=True).get()
         except Channel.DoesNotExist:
+            if getattr(settings, 'OPPS_MULTISITE_FALLBACK', None):
+                return super(ChannelManager, self).get_query_set().filter(
+                    homepage=True, published=True)[0]
             return None
 
 
@@ -31,6 +34,9 @@ class Channel(MPTTModel, Publishable, Slugged):
                               default="default")
     description = models.CharField(_(u"Description"),
                                    max_length=255, null=True, blank=True)
+    hat = models.CharField(_(u"Hat"),
+                           max_length=255, null=True, blank=True)
+
     show_in_menu = models.BooleanField(_(u"Show in menu?"), default=False)
     include_in_main_rss = models.BooleanField(
         _(u"Show in main RSS?"),
@@ -47,7 +53,7 @@ class Channel(MPTTModel, Publishable, Slugged):
     parent = TreeForeignKey('self', related_name='subchannel',
                             null=True, blank=True,
                             verbose_name=_(u'Parent'))
-
+    paginate_by = models.IntegerField(_("Paginate by"), null=True, blank=True)
     objects = ChannelManager()
 
     class Meta:
