@@ -7,7 +7,17 @@ from opps.db.models.fields.jsonf import JSONFormField
 from opps.fields.widgets import JSONField
 from opps.fields.models import Field, FieldOption
 
-from .models import Container
+from .models import Container, ContainerBoxContainers
+
+
+class ContainerBoxContainersInlineForm(forms.ModelForm):
+    def __init__(self, *args, **kwargs):
+        super(ContainerBoxContainersInlineForm,
+              self).__init__(*args, **kwargs)
+        self.fields['order'].widget.attrs['readonly'] = True
+
+    class Meta:
+        model = ContainerBoxContainers
 
 
 class ContainerAdminForm(forms.ModelForm):
@@ -15,7 +25,7 @@ class ContainerAdminForm(forms.ModelForm):
         super(ContainerAdminForm, self).__init__(*args, **kwargs)
 
         if not settings.OPPS_MIRROR_CHANNEL:
-            self.fields['mirror_channel'].widget = forms.HiddenInput()
+            self.fields['mirror_channel'].widget.attrs['disabled'] = True
 
         self.fields['json'] = JSONFormField(
             widget=JSONField(
