@@ -32,6 +32,14 @@ class Owned(models.Model):
         abstract = True
 
 
+class OwnedNotRequired(models.Model):
+    user = models.ForeignKey(settings.AUTH_USER_MODEL,
+                             blank=True, null=True)
+
+    class Meta:
+        abstract = True
+
+
 class Publisher(Date):
 
     site = models.ForeignKey(Site, default=1)
@@ -45,6 +53,12 @@ class Publisher(Date):
         max_length=100,
         null=True, blank=True,
         db_index=True)
+    mirror_site = models.ManyToManyField(
+        'sites.Site',
+        related_name="%(app_label)s_%(class)s_mirror_site",
+        null=True, blank=True,
+        verbose_name=_(u"Mirror site"),
+    )
     date_available = models.DateTimeField(
         _(u"Date available"),
         default=timezone.now,
@@ -260,6 +274,9 @@ class Imaged(models.Model):
             ci.image_id: ci.caption for ci in self.containerimage_set.all()
         }
 
+        if self.main_image:
+            captions[self.main_image.id] = self.main_image.caption
+
         for im in imgs:
             caption = captions.get(im.pk)
             if caption:
@@ -320,12 +337,14 @@ class Config(Publishable):
         'containers.Container',
         null=True, blank=True,
         help_text=_(u'Only published container'),
-        on_delete=models.SET_NULL
+        on_delete=models.SET_NULL,
+        verbose_name=_(u'Container')
     )
     channel = models.ForeignKey(
         'channels.Channel',
         null=True, blank=True,
-        on_delete=models.SET_NULL
+        on_delete=models.SET_NULL,
+        verbose_name=_(u'Channel')
     )
 
     class Meta:
