@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 from django.views.generic.list import ListView as DjangoListView
-from django.contrib.sites.models import get_current_site
+from django.contrib.sites.models import Site, get_current_site
 from django.utils import timezone
 from django.conf import settings
 
@@ -13,9 +13,8 @@ from opps.containers.models import Mirror, ContainerBox
 class ListView(View, DjangoListView):
     template_name_suffix = ''
 
-    def get_template_names(self):
+    def get_template_list(self, domain_folder="containers"):
         templates = []
-        domain_folder = self.get_template_folder()
 
         if not self.long_slug:
             templates.append('{}/none.html'.format(domain_folder))
@@ -65,10 +64,22 @@ class ListView(View, DjangoListView):
                                                            list_name))
 
         templates.append('{}/{}.html'.format(domain_folder, list_name))
+
         return templates
 
+    def get_template_names(self):
+        domain_folder = self.get_template_folder()
+        template_list = self.get_template_list(domain_folder)
+
+        if domain_folder != "containers":
+            template_list.extend(self.get_template_list())
+
+        return template_list
+
     def get_queryset(self):
+        self.fallback = getattr(settings, 'OPPS_MULTISITE_FALLBACK', False)
         self.site = get_current_site(self.request)
+        self.site_master = Site.objects.order_by('id')[0]
         self.long_slug = self.get_long_slug()
 
         if not self.long_slug:
@@ -88,7 +99,7 @@ class ListView(View, DjangoListView):
 
         queryset = super(ListView, self).get_queryset()
         filters = {}
-        filters['site_domain'] = self.site.domain
+        filters['site_domain__in'] = [self.site.domain]
         filters['channel_long_slug__in'] = self.channel_long_slug
         filters['date_available__lte'] = timezone.now()
         filters['published'] = True
@@ -99,6 +110,8 @@ class ListView(View, DjangoListView):
         if self.request.GET.get('type'):
             filters['child_class'] = self.request.GET.get('type')
 
+        if self.fallback and self.site != self.site_master:
+            filters.get('site_domain__in', []).append(self.site_master.domain)
         queryset = queryset.filter(**filters)
         if self.excluded_ids:
             queryset = queryset.exclude(
